summaryrefslogtreecommitdiffstats
path: root/build/jenkins-build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build/jenkins-build.sh')
-rwxr-xr-xbuild/jenkins-build.sh29
1 files changed, 23 insertions, 6 deletions
diff --git a/build/jenkins-build.sh b/build/jenkins-build.sh
index 04f8da6..0c397b1 100755
--- a/build/jenkins-build.sh
+++ b/build/jenkins-build.sh
@@ -1,12 +1,29 @@
#!/usr/bin/env bash
# Script to builds source code in Jenkins environment
+module try-load conda
-module avail
-module load conda
-# it expects that git clone is done before this script launch
+# install miniconda if the module is not present
+if hash conda 2>/dev/null; then
+ echo using conda
+else
+ if [ ! -f Miniconda3-latest-Linux-x86_64.sh ]; then
+ wget -q https://repo.continuum.io/miniconda/Miniconda3-latest-Linux-x86_64.sh
+ chmod +x Miniconda3-latest-Linux-x86_64.sh
+ fi
+ ./Miniconda3-latest-Linux-x86_64.sh -u -b -p .
+ PATH=$PATH:./bin
+fi
+
+# presume that git clone is done before this script launch
# git clone https://github.com/vais-ral/CCPi-Regularisation-Toolkit
-conda install conda-build
+conda install -y conda-build
#export CIL_VERSION=0.10.2
-export CIL_VERSION=0.10.2
-cd CCPi-Regularisation-Toolkit
+if [[ -n ${CIL_VERSION} ]]
+then
+ echo Using defined version: $CIL_VERSION
+else
+ export CIL_VERSION=0.10.3
+ echo Defining version: $CIL_VERSION
+fi
+#cd CCPi-Regularisation-Toolkit # already there by jenkins
conda build Wrappers/Python/conda-recipe